;  ***************************************************************************
;  *                                                                         *
;  * File:   dosver.asm           Version  1.01            Date: 1998-11-14  *
;  *                                                                         *
;  * Copyright (C) 1993-1998 by Kostis Netzwerkberatung                      *
;  * Talstr. 25, D-63322 Rdermark, Tel. +49 6074 881056, FAX 881058         *
;  * kosta@kostis.net (Kosta Kostis), http://www.kostis.net/                 *
;  *                                                                         *
;  ***************************************************************************
;  *                                                                         *
;  * Function:                                                               *
;  *     - return MS-DOS version via DOS ERRORLEVEL and display it           *
;  *       ERRORLEVEL:                                                       *
;  *           0        MS-DOS 1.x                                           *
;  *          10 * major version + subversion (high digit)                   *
;  *       Examples:                                                         *
;  *         MS-DOS 3.31  -  33                                              *
;  *         MS-DOS 5.00  -  50                                              *
;  *         MS-DOS 6.22  -  62                                              *
;  *                                                                         *
;  ***************************************************************************
;  *                                                                         *
;  * Comments:                                                               *
;  *                                                                         *
;  * With Microsoft's Macro Assembler 6.0 type:   ml /AT /cp killmbr.asm     *
;  * With Borland's   Turbo Assembler 2.5 type:   tasm /ml killmbr.asm       *
;  *                                              tlink /t killmbr.obj       *
;  *                                                                         *
;  ***************************************************************************
;  *                                                                         *
;  * History:                                                                *
;  *    1998-11-14 KK V1.01                                                  *
;  *        - brushed up program using macros                                *
;  *    1993-08-14 KK V1.00                                                  *
;  *        - initial coding                                                 *
;  *                                                                         *
;  ***************************************************************************

.MODEL          TINY

.CONST

;  ***************************************************************************
;
;	MS-DOS service functions
;
;  ***************************************************************************

INT_OLDTERM	EQU	20h		; terminate DOS 1.x program
INT_DOS		EQU	21h		; MS-DOS Service Interrupt
   DOS_PUTCHR	EQU	02h		;    display character in DL
   DOS_PUTSTR	EQU	09h		;    display string terminated by '$'
   DOS_GETVER	EQU	30h		;    return DOS version in AL:AH
   DOS_TERM	EQU	4Ch		;    terminate program

;  ***************************************************************************
;
;	personal C style macros to ease coding
;
;  ***************************************************************************

doscall		MACRO	Function		; call MS-DOS Function

		mov	ah,Function		;
		int	INT_DOS			;

		ENDM				;

putc		MACRO	Char			; write char to stdout

		mov	dl,Char			;
		doscall	DOS_PUTCHR		;

		ENDM				;

putbcd		MACRO	Digit			;

		mov	dl, Digit		; copy bcd digit
		or	dl, '0'			; convert to ascii
		doscall	DOS_PUTCHR		; display digit

		ENDM				;

puts		MACRO	String			; write string to stdout

		lea	dx,String		; must be terminated by a '$'
		doscall	DOS_PUTSTR		;

		ENDM				;

;  ***************************************************************************
;
;	Program Constants
;
;  ***************************************************************************

CR		EQU	13
LF		EQU	10
EOS		EQU	'$'

;  ***************************************************************************
;
;	Program Messages
;
;  ***************************************************************************

DOSVerMsg	DB	'MS-DOS Version ', EOS	;
DOSVerMsgDOS1	DB	'1.x'			;
CRLF		DB	CR, LF, EOS		;

;  ***************************************************************************
;
;	Main Program
;
;  ***************************************************************************

.CODE

		ORG	100h			;

start:		puts	CRLF			; display CR/LF
		puts	DOSVerMsg		; just like VER

		doscall	DOS_GETVER		; now get the version number

		cmp	al,2			; is it DOS 1.x?
		jl	ancientdos		; yeah, terminate the old way!

		mov	cx,ax			; keep version

		putbcd	al			; display major version
		putc	'.'			; display dot

		mov     al,ch                   ; display minor version
		cbw                             ;
		mov     bl,10                   ;
		div     bl                      ; divide by 10
		mov     bl,ah                   ; keep remainder
		mov     bh,al                   ; *and* minor version

		putbcd	al			; first digit after '.'
		putbcd	bl			; second digit

		puts	CRLF			; display CR/LF
		puts	CRLF			; just like VER

		mov     al,cl                   ; multiply major version by 10
		mov     bl,10                   ;
		mul     bl                      ;

		add     al,bh                   ; add minor version

		doscall	DOS_TERM		; terminate program

ancientdos:	puts	DOSVerMsgDOS1		; DOS version 1.x
		int	INT_OLDTERM		; DOS 1.x terminate program

		END	start			;
